pub struct CodeGenerator { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world code-generator.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
CodeGenerator::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
CodeGeneratorPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesCodeGeneratorPre::instantiateto create aCodeGenerator. -
If you’ve instantiated the instance yourself already then you can use
CodeGenerator::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl CodeGenerator
impl CodeGenerator
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<CodeGenerator>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<CodeGenerator>
Convenience wrapper around CodeGeneratorPre::new and
CodeGeneratorPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<CodeGenerator>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<CodeGenerator>
Convenience wrapper around CodeGeneratorIndices::new and
CodeGeneratorIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: HostWithStore + HostWithStore + HostWithStore,
for<'a> D::Data<'a>: Host + Host + Host,
T: 'static,
pub fn forge_plugin_generator_api(&self) -> &Guest