pub struct CodeGeneratorIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
code-generator.
This is an implementation detail of CodeGeneratorPre and can
be constructed if needed as well.
For more information see CodeGenerator as well.
Implementations
Sourceimpl CodeGeneratorIndices
impl CodeGeneratorIndices
Sourcepub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
Creates a new copy of CodeGeneratorIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<CodeGenerator>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<CodeGenerator>
Uses the indices stored in self to load an instance
of CodeGenerator from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.