BindgenError

Enum BindgenError 

pub enum BindgenError {
    DanglingTypeRef(String),
    DanglingDiscriminator {
        type_ref: String,
    },
    DuplicateTypeId(String),
    BadStatusRange(u8),
    DanglingValueRef(u32),
}
Errors returned when fallible conversions hit a boundary violation.

Variants



DanglingTypeRef(String)

A TypeRef referred to a type id that did not appear in forge_ir::Ir::types.



DanglingDiscriminator

A discriminator mapping referenced a type id that did not appear in forge_ir::Ir::types.

Fields

type_ref: String


DuplicateTypeId(String)

The same type id appeared more than once in forge_ir::Ir::types.



BadStatusRange(u8)

A status range outside 1..=5 was encountered.



DanglingValueRef(u32)

A ValueRef index was out of bounds for forge_ir::Ir::values.